--[[
-- Copyright 2017 AKA Russell
--
-- This file is part of Scarlet.
--
-- Scarlet is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- Scarlet is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Scarlet.  If not, see <http://www.gnu.org/licenses/>.
--]]

--[[
-- A module containing all the items defined for this game. In Scarlet Moon,
-- the only items we have are articles of clothing. In addition to the standard
-- keys (name, description, slots), Scarlet Moon clothing has two additional
-- keys:
-- 1. risque - A measure of how revealing the clothing is. 1 is modest and
-- normal (i.e. a standard t-shirt), 5 is barely covers anything at all (i.e.
-- a thong). These are used by dynamic text functions when people are
-- reacting to a character's outfit.
-- 2. type - A string describing the type of equipment
-- (i.e. shirt, pants, skirt). This is used by some dynamic text when people
-- are interacting with their (or another person's) clothing.
]]

local M = {}
local pcitems = require 'data/pcitems'

for name, item in pairs(pcitems) do
    M[name] = item
end

M["waiter shirt"] = {
    name="waiter shirt",
    description="A black vest over a fitted shirt and white bowtie. Worn to work.",
    slots={"upper"},
    risque=1
}

M["waitress vest"] = {
    name="waitress vest",
    description="A tight sleeveless vest black with deep cleavage that leaves the belly button exposed.",
    slots={"upper"},
    risque=4
}

M["short waitress skirt"] = {
    name="short waitress skirt",
    description="A tight white skirt that extends just under the bottom.",
    slots={"lower"},
    risque=4
}

M["waiter vest"] = {
    name="waiter vest",
    description="A tight black sleeveless vest.",
    slots={"upper"},
    risque=4
}

M["tight waiter pants"] = {
    name="tight waiter pants",
    description="A pair of tight white slacks.",
    type="pants",
    slots={"lower"},
    risque=4
}

M["waiter pants"] = {
   name="waiter pants",
   description="A pair of black slacks. Worn to work.",
   slots={"lower"},
   type="pants",
   risque=1
}

M["waitress skirt"] = {
  name="waitress skirt",
  description="A tight black skirt that extends to just above your knees. Worn to work.",
  slots={"lower"},
  risque=2,
  type="skirt"
}

M["thong bikini"] = {
    name="thong bikini",
    risque=8,
    slots={"lower", "upper", "underwear"},
    type="underwear",
    description="A black thong bikini that leaves your cheeks completely exposed."
}

M["studded leather jacket"] = {
    name="studded leather jacket",
    risque=1,
    slots={"upper"},
    type="shirt",
    description="A black leather jacket covered in studs"
}

M["bare chest"] = {
    name="bare chest",
    risque=0,
    slots={"upper"},
    type="shirt",
    description="Your chest."
}

M["Succubus Minion Costume"] = {
    name="Succubus Minion Costume",
    risque=7,
    slots={"lower", "upper", "underwear"},
    type="underwear",
    description="A skimpy black thong leotard worn by Succubus' minions."
}

M["studded thong"] = {
    name="studded thong",
    risque=6,
    slots={"underwear"},
    type="underwear",
    description="A black thong with studs across the front, and on the backing triangle"
}

M["scarlet shorts"] = {
    name="scarlet shorts",
    risque=7,
    slots={"lower", "upper", "underwear"},
    type="costume",
    description="A pair of small and tight spandex shorts, boots and a half-mask."
}

M["tie bikini"] = {
    name="tie bikini",
    risque=3,
    slots={"lower", "upper", "underwear"},
    type="underwear",
    description="A black tie-side full cut bikini."
}

M["one piece bathing suit"] = {
    name="one piece bathing suit",
    risque=2,
    slots={"lower", "upper", "underwear"},
    type="underwear",
    description="A maroon full cut one piece bathing suit."
}

M["scarletsuit"] = {
    name="scarletsuit",
    risque=2,
    slots={"lower", "upper", "underwear"},
    type="costume",
    description="A superheroine costume very similar to a track speedsuit."
}

M["scarlet thong"] = {
    name="scarlet thong",
    risque=7,
    slots={"lower", "upper", "underwear"},
    type="costume",
    description="A crimson halter top, a thong and high-heeled boots."
}

M["bottom"] = {
    name="bottom",
    risque=6,
    slots={"underwear"},
    type="underwear",
    description="Your bare ass. Put some pants on, jackass!"
}

M["red dress"] = {
    name="red dress",
    risque=2,
    slots={"lower", "upper"},
    type="dress",
    description="An elegant red dress with a plunging neckline and a floor"
        .. " length hem."
}

M["blue dress"] = {
    name="blue dress",
    risque=2,
    slots={"lower", "upper"},
    type="dress",
    description="An elegant blue dress with a plunging neckline and a floor "
        .. "length hem."
}

M["white dress"] = {
    name="white dress",
    risque=2,
    slots={"lower", "upper"},
    type="dress",
    description="An elegant white dress with a plunging neckline and a floor "
        .. "length hem."
}


M["black jeans with chain"] = {
    name="black jeans with chain",
    risque=1,
    slots={"lower"},
    type="pants",
    description="A pair of skintight black jeans with a large, heavy chain "
        .. "hanging off of them."
}

M["thong speedo"] = {
    name="thong speedo",
    risque=8,
    slots={"lower", "underwear"},
    type="underwear",
    description="A black thong speedo that leaves pretty much everything but your anus and junk exposed."
}

M["chest"] = {
    name="chest",
    risque=8,
    slots={"upper"},
    type="shirt",
    description="Your bare chest."
}


M["succubus costume"] = {
    name="succubus costume",
    risque=7,
    slots={"lower", "upper", "underwear"},
    type="underwear",
    description="A skimpy black thong leotard worn by Succubus."
}

M["speedo"] = {
    name="speedo",
    risque=3,
    slots={"lower", "underwear"},
    type="underwear",
    description="A dark blue speedo."
}

M["swim trunks"] = {
    name="swim trunks",
    risque=2,
    slots={"lower", "underwear"},
    type="underwear",
    description="A pair of maroon swim trunks."
}

M["long-sleeved black dress"] = {
    name="long-sleeved black dress",
    risque=3,
    slots={"upper", "lower"},
    type="dress",
    description="Tight black dress with long sleeves."
}

M["pvc bra"] = {
    name="pvc bra",
    risque=5,
    slots={"upper"},
    description="A red PVC bra with fiery swirls.",
    type="shirt"
}

M["pvc hotpants"] = {
    name="pvc hotpants",
    risque=4,
    slots={"lower"},
    description="A pair of tiny red PVC hotpants with fiery swirls.",
    type="pants"
}

M["bottom"] = {
    name="bottom",
    risque=8,
    slots={"underwear"},
    description="Your bare bottom. Maybe you should put on some panties.",
    type="underwear"
}

M["tempestas tanktop"] = {
    name="tempestas tanktop",
    risque=4,
    slots={"upper"},
    description="A long-sleeved spandex top with a red tornado on the chest.",
    type="shirt"
}

M["tempestas g-string"] = {
    name="tempestas g-string",
    risque=6,
    slots={"underwear"},
    description="A white g-string with a red tornado on the crotch.",
    type="thong"
}

M["tempestas pants"] = {
    name="tempestas pants",
    risque=3,
    slots={"lower"},
    description="A pair of white painted-on spandex pants worn by Tempestas.",
    type="pants"
}

M["sports-bra"] = {
    name="sports-bra",
    risque=4,
    slots={"upper"},
    description="A sports bra that compresses ones chest for sporty things.",
    type="shirt"
}

M["lycra-shorts"] = {
    name="lycra-shorts",
    risque=4,
    slots={"lower"},
    description="A pair of *very* short workout shorts.",
    type="shorts"
}


M["sleeveless tanktop"] = {
    name="sleeveless tanktop",
    risque=3,
    slots={"upper"},
    description="A tanktop without sleeves, really shows off the shoulders.",
    type="shirt"
}

M["male running shorts"] = {
    name="male running shorts",
    risque=4,
    slots={"lower"},
    description="A pair of *very* short workout shorts.",
    type="shorts"
}

M["pretty prink dress"] = {
    name="pretty prink dress",
    risque=0,
    slots={"upper", "lower"},
    description="A childish pink dress with a little bear design on the right breast.",
    type="dress"
}

M["bear-dotted panties"] = {
    name="bear-dotted panties",
    risque=2,
    slots={"underwear"},
    description="A pair of childish panties with little teddy bears on them. A bit small for an adult.",
    type="underwear"
}


M["anklyana leotard"] = {
    name="anklyana leotard",
    risque=3,
    slots={"upper", "lower", "underwear"},
    description="A revealing, high cut leotard that shows off Anklyana's big bottom",
    type="underwear"
}

M["little blue dress"] = {
    name="little blue dress",
    risque=3,
    slots={"upper", "lower"},
    description="A very blue small dress that David will love.",
    type="dress"
}


M["sleeveless vest"] = {
    name="sleeveless vest",
    risque=2,
    slots={"upper"},
    description="A sleeveless vest that shows off your physique.",
    type="vest"
}


M["skintight leather pants"] = {
    name="skintight leather pants",
    risque=3,
    slots={"lower"},
    description="A pair of skintight leather pants that covers everything and obscures nothing.",
    type="pants"
}

M["leopard-print bra"] = {
    name="leopard-print bra",
    risque=4,
    slots={"upper"},
    description="A leopard-print bra."
}

M["leopard-print leggings"] = {
    name="leopard-print leggings",
    risque=3,
    slots={"lower"},
    description="A pair of skintight leopard-print leggings."
}

M["tube dress"] = {
    name="tube dress",
    risque=4,
    slots={"upper", "lower"},
    description="A tight, white, slightly sheer tube dress with a floral pattern across the chest.",
    type="dress"
}

M["police uniform shirt"] = {
    name="police uniform shirt",
    risque=0,
    slots={"upper"},
    description="The top of a police uniform.",
    type="shirt"
}


M["police uniform pants"] = {
    name="police uniform pants",
    risque=0,
    slots={"lower"},
    description="The bottom of a police uniform.",
    type="pants"
}

M["bright bustier"] = {
    name="bright bustier",
    risque=5,
    slots={"upper"},
    description="A low-cut bustier with golden boning.",
    type="shirt"
}

M["bright skirt"] = {
    name="bright skirt",
    risque=6,
    slots={"lower"},
    description="A sheer, gauzy skirt that only covers half her bottom.",
    type="shirt"
}

M["bright thong"] = {
    name="bright thong",
    risque=6,
    slots={"underwear"},
    description="A golden thong worn by Bright.",
    type="shirt"
}


M["french maid"] = {
    name="french maid",
    risque=9,
    slots={"upper", "lower"},
    description="A skimpy French maid outfit Buzzsaw forces the player to wear.",
    type="dress"
}


M["chainmail bikini"] = {
    name="chainmail bikini",
    risque=9,
    slots={"upper", "lower", "underwear"},
    description="A skimpy chainmail bikini.",
    type="shirt"
}

return M
